OC.L10N.register(
    "mail",
    {
    "Creating account failed: " : "аккаунт үүсгэж чадсангүй:",
    "Mail" : "шуудан",
    "Name" : "нэр",
    "Mail Address" : "шуудангийн хаяг",
    "Password" : "нууц үг",
    "None" : "юу ч үгүй",
    "IMAP Port" : "интернет мессеж хандалтын протокол -ийн порт",
    "IMAP User" : "интернет мессеж хандалтын протокол -ийн хэрэглэгч",
    "IMAP Password" : "интернет мессеж хандалтын протокол -ийн нууц үг",
    "SMTP Host" : "Энгийн мэйл дамжуулах протокол-ийн хост",
    "SMTP Port" : "Энгийн мэйл дамжуулах протокол-ийн порт",
    "SMTP User" : "Энгийн мэйл дамжуулах протокол-ийн хэрэглэгч",
    "SMTP Password" : "Энгийн мэйл дамжуулах протокол-ийн нууц үг",
    "Save" : "Хадгалах",
    "Connect" : "холбох",
    "Add mail account" : "шуудангийн хаяг нэмэх",
    "Select account" : "Аккаунт сонгох",
    "Subject" : "Сэдэв",
    "Add attachment from Files" : "Файлаас хавсралт нэмэх",
    "Sending …" : "илгээмж",
    "Go back" : "Буцах",
    "Retry" : "Дахин оролдох",
    "Message sent!" : "зурвас илгээсэн",
    "Send" : "илгээх",
    "Select" : "Сонгох",
    "Delete" : "Устгах",
    "Favorites" : "Онцолсон",
    "Other" : "Бусад",
    "Attachments" : "Хавсралт",
    "Download attachment" : "Татаж авах хавсралт",
    "Save to Files" : "Файлд хадгална",
    "Choose a folder to store the attachment in" : "-д хавсралт хадгалах фолдер сонгоно уу",
    "Save all to Files" : "бүх файлыг хадгалах",
    "The images have been blocked to protect your privacy." : " таны хувийн нууцыг хамгаалахын тулд дүрсийг хаасан байна.",
    "Show images from this sender" : " илгээгчээс харуулах зургууд",
    "New message" : "шинэ зурвас",
    "Settings" : "тохиргоо",
    "Quota" : " хувь хэмжээ",
    "Add folder" : "Add folder",
    "Saving" : "хадгаламж",
    "Remove account" : "Аккаунт устгах",
    "Cancel" : "болиулах",
    "Show all folders" : "Бүх хавтас харуулах",
    "Delete folder" : "Хавтсыг устгах",
    "Signature" : "Гарын үсэг",
    "Reply" : "хариулт",
    "Forward" : "дамжих",
    "General" : "Ерөнхий",
    "User" : "Хэрэглэгч",
    "Host" : "хост",
    "Port" : "порт",
    "Keyboard shortcut" : "Keyboard товчлуур",
    "Search" : "Хайх",
    "Refresh" : "Сэргээх",
    "Connect your mail account" : "Таны мэйл бүртгэлийг холбоно",
    "All" : "бүх",
    "Archive" : "архив",
    "Drafts" : "ноорог",
    "Inbox" : "ирсэн",
    "Junk" : "хэрэггүй",
    "Sent" : "илгээсэн",
    "Trash" : "хог",
    "Error loading message" : "алдаатай ачааллах зурвас"
},
"nplurals=2; plural=(n != 1);");
